==> vdocipher_flutter-2.2.0.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/VdoPlayerPlatformView.java <==
package com.vdocipher.flutter.vdoplayer;

import android.content.Context;
import android.util.Log;
import android.view.View;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.vdocipher.aegis.media.ErrorDescription;
import com.vdocipher.aegis.media.Track;
import com.vdocipher.aegis.offline.VdoDownloadManager;
import com.vdocipher.aegis.player.PlayerHost;
import com.vdocipher.aegis.player.VdoPlayer;
import com.vdocipher.aegis.player.VdoInitParams;
import com.vdocipher.aegis.player.VdoPlayerView;
import com.vdocipher.aegis.player.PlaybackState;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.platform.PlatformView;

import java.util.HashMap;
import java.util.Map;

class VdoPlayerPlatformView implements PlatformView, MethodChannel.MethodCallHandler,
        VdoPlayer.PlaybackEventListener {
    private static final String TAG = "VdoPlayerPlatformView";

    @NonNull private final VdoPlayerView vdoPlayerView;
    @NonNull private final MethodChannel methodChannel;
    @NonNull private final EventChannel eventChannel;

    @Nullable private VdoPlayer vdoPlayer;
    @Nullable private EventChannel.EventSink playerEventSink;

    @Nullable private MethodChannel.Result loadResult;
    @Nullable private PlaybackState lastPlaybackState;

    //Keeping track of current playback speed to restore it on app resume as its not supported by android SDK.
    private float currentPlaybackSpeed;

    VdoPlayerPlatformView(@NonNull Context context, final int id, BinaryMessenger binaryMessenger,
                          @Nullable final Map<String, Object> creationParams) {
        vdoPlayerView = new VdoPlayerView(context);
        methodChannel = new MethodChannel(binaryMessenger, "com.vdocipher.flutter.vdoplayerview_" + id);
        methodChannel.setMethodCallHandler(this);

        eventChannel = new EventChannel(binaryMessenger, "com.vdocipher.flutter.vdoplayerview.events_" + id);
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object arguments, EventChannel.EventSink eventSink) {
                playerEventSink = eventSink;
            }

            @Override
            public void onCancel(Object arguments) {
                playerEventSink = null;
            }
        });

        vdoPlayerView.initialize(new PlayerHost.InitializationListener() {
            @Override
            public void onInitializationSuccess(PlayerHost playerHost, VdoPlayer player, boolean restored) {
                Log.i(TAG, "init success");
                player.addPlaybackEventListener(VdoPlayerPlatformView.this);
                vdoPlayer = player;
                methodChannel.invokeMethod("onPlatformPlayerCreated", id);
            }
            @Override
            public void onInitializationFailure(PlayerHost playerHost, ErrorDescription errorDescription) {
                Log.e(TAG, "init failure");
            }
        });
    }

    @NonNull
    @Override
    public View getView() {
        return vdoPlayerView;
    }

    @Override
    public void dispose() {
        vdoPlayerView.packUp();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        if (vdoPlayer == null) {
            return;
        }

        switch (call.method) {
            case "load":
                // TODO handle load args parse failure
                Map<String, Object> loadArgs = (Map<String, Object>)call.arguments;
                final boolean restore = (boolean)loadArgs.get("restore");
                if (restore) {
                    // Restore with last saved playback state
                    if (lastPlaybackState == null) {
                        // Nothing to restore with
                        result.success(MessageUtils.loadResultMap(null));
                    } else {
                        // Restore
                        vdoPlayerView.restore(lastPlaybackState);
                        lastPlaybackState = null;
                        loadResult = result;
                    }
                } else {
                    // Load new provided EmbedInfo
                    Map<String, Object> embedInfo = (Map<String, Object>)loadArgs.get("embedInfo");
                    VdoInitParams initParams = new EmbedInfoToVdoInitParams(embedInfo).convert();
                    Log.i("ReceivedParams", "[" + initParams.otp + ", " + initParams.playbackInfo + "]");
                    vdoPlayer.load(initParams);
                    loadResult = result;
                }
                break;
            case "setPlayWhenReady":
                vdoPlayer.setPlayWhenReady((boolean)call.arguments);
                break;

            case "getPlayWhenReady":
                result.success(vdoPlayer.getPlayWhenReady());
                break;

            case "getPlaybackAndBufferedPositions":
                HashMap<String, Object> positions = new HashMap<>();
                long currentTime = vdoPlayer.getCurrentTime();
                long bufferedTime = vdoPlayer.getBufferedTime();
                positions.put("position", currentTime >= 0 ? currentTime : 0);
                positions.put("bufferedPosition", bufferedTime >= 0 ? bufferedTime : 0);
                result.success(positions);
                break;

            case "getDuration":
                result.success(vdoPlayer.getDuration());
                break;

            case "seek":
                vdoPlayer.seekTo((int)call.arguments);
                result.success(null);
                break;

            case "stop":
                vdoPlayerView.packUp();
                result.success(null);
                break;
            case "packUp":
                lastPlaybackState = vdoPlayerView.getLastPlaybackState();
                vdoPlayerView.packUp();
                result.success(null);
                break;
            case "setPlaybackSpeed":
                double speed = (double)call.arguments;
                vdoPlayer.setPlaybackSpeed((float)speed);
                result.success(null);
                break;
            case "setAdaptive":
                vdoPlayer.setSelectedTracks(new Track[]{Track.SET_ADAPTIVE});
                result.success(null);
                break;
            case "setAudioTrack":
                // Fall over; same as video track selection
            case "setVideoTrack":
                int trackId = (int)call.arguments;
                setTrack(trackId);
                result.success(null);
                break;
            case "setSubtitleLanguage":
                String subtitleLang = (String)call.arguments;
                boolean changed = setSubtitleLanguage(subtitleLang);
                result.success(changed);
                break;
            case "getPlaybackProperty":
                String propertyName = (String) call.arguments;
                Object playbackProperty = vdoPlayer.getPlaybackProperty(propertyName);
                result.success(playbackProperty);
                break;
            default:
                result.notImplemented();
        }
    }

    // VdoPlayer.PlaybackEventListener impl

    @Override
    public void onPlayerStateChanged(boolean playWhenReady, int playbackState) {
        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onPlayerStateChanged");
            event.put("playWhenReady", playWhenReady);
            event.put("playbackState", MessageUtils.playerStateName(playbackState));
            playerEventSink.success(event);
        }
    }

    @Override
    public void onSeekTo(long millis) {
        methodChannel.invokeMethod("onSeekTo", millis);
    }

    @Override
    public void onProgress(long millis) {
        methodChannel.invokeMethod("onProgress", millis);
    }

    @Override
    public void onBufferUpdate(long bufferTime) {
        methodChannel.invokeMethod("onBufferUpdate", bufferTime);
    }

    @Override
    public void onPlaybackSpeedChanged(float speed) {
        this.currentPlaybackSpeed = speed;
        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onPlaybackSpeedChanged");
            event.put("value", speed);
            playerEventSink.success(event);
        }
    }

    @Override
    public void onLoading(VdoInitParams vdoInitParams) {
        Log.i(TAG, "onLoading");
        methodChannel.invokeMethod("onLoading", VdoInitParamsToMap.convert(vdoInitParams));
    }

    @Override
    public void onLoaded(VdoInitParams vdoInitParams) {
        Log.i(TAG, "onLoaded");
        methodChannel.invokeMethod("onLoaded", VdoInitParamsToMap.convert(vdoInitParams));
        if (loadResult != null && vdoPlayer != null) {
            //Resetting playback speed
            if (vdoPlayer.getPlaybackSpeed() != currentPlaybackSpeed)
                vdoPlayer.setPlaybackSpeed(currentPlaybackSpeed);
            loadResult.success(MessageUtils.loadResultMap(vdoPlayer.getCurrentMedia()));
            loadResult = null;
        }

        if (playerEventSink != null && vdoPlayer!=null) {
            Track[] availableTracks = vdoPlayer.getAvailableTracks();
            Track[] selectedTracks = vdoPlayer.getSelectedTracks();
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onTracksChanged");
            event.put("available", MessageUtils.trackMapList(availableTracks));
            event.put("selected", MessageUtils.trackMapList(selectedTracks));
            playerEventSink.success(event);
        }
    }

    @Override
    public void onLoadError(VdoInitParams vdoInitParams, ErrorDescription errorDescription) {
        Log.e(TAG, "onLoadError " + errorDescription);
        if (loadResult != null) {
            // TODO define error object
            loadResult.error("" + errorDescription.errorCode, errorDescription.errorMsg, null);
            loadResult = null;
        }
    }

    @Override
    public void onMediaEnded(VdoInitParams vdoInitParams) {
        methodChannel.invokeMethod("onMediaEnded", VdoInitParamsToMap.convert(vdoInitParams));
        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onMediaEnded");
            playerEventSink.success(event);
        }
    }

    @Override
    public void onError(VdoInitParams vdoInitParams, ErrorDescription errorDescription) {
        Map<String, Object> arguments = new HashMap<>();
        arguments.put("embedInfo", VdoInitParamsToMap.convert(vdoInitParams));
        arguments.put("errorDescription", MessageUtils.errorInfoMap(errorDescription));
        methodChannel.invokeMethod("onError", arguments);
        if (playerEventSink != null) {
            playerEventSink.error("" + errorDescription.errorCode, errorDescription.errorMsg, null);
        }
    }

    @Override
    public void onTracksChanged(Track[] availableTracks, Track[] selectedTracks) {
        Map<String, Object> arguments = new HashMap<>();
        arguments.put("available", MessageUtils.trackMapList(availableTracks));
        arguments.put("selected", MessageUtils.trackMapList(selectedTracks));
        methodChannel.invokeMethod("onTracksChanged", arguments);

        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onTracksChanged");
            event.put("available", MessageUtils.trackMapList(availableTracks));
            event.put("selected", MessageUtils.trackMapList(selectedTracks));
            playerEventSink.success(event);
        }
    }

    private void setTrack(final int trackId) {
        if (vdoPlayer == null) {
            return;
        }
        // Find track with trackId in available tracks
        Track match = null;
        for (Track track : vdoPlayer.getAvailableTracks()) {
            if (track.id == trackId) {
                match = track;
                break;
            }
        }

        // If track found, select it
        if (match != null) {
            vdoPlayer.setSelectedTracks(new Track[]{match});
        }
    }

    private boolean setSubtitleLanguage(String lang) {
        if (vdoPlayer == null) {
            return false;
        }
        if (lang == null) {
            // Turn subtitles off
            vdoPlayer.setSelectedTracks(new Track[]{Track.DISABLE_CAPTIONS});
            return true;
        } else {
            // Set provided subtitle language if available
            Track[] tracks = vdoPlayer.getAvailableTracks();
            for (Track track : tracks) {
                if (track.type == Track.TYPE_CAPTIONS && lang.equals(track.language)) {
                    vdoPlayer.setSelectedTracks(new Track[]{track});
                    return true;
                }
            }
            return false;
        }
    }
}

==> vdocipher_flutter-2.2.7.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/VdoPlayerPlatformView.java <==
package com.vdocipher.flutter.vdoplayer;

import android.content.Context;
import android.util.Log;
import android.view.View;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.vdocipher.aegis.media.ErrorDescription;
import com.vdocipher.aegis.media.Track;
import com.vdocipher.aegis.player.PlaybackState;
import com.vdocipher.aegis.player.PlayerHost;
import com.vdocipher.aegis.player.VdoInitParams;
import com.vdocipher.aegis.player.VdoPlayer;
import com.vdocipher.aegis.player.VdoPlayerView;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.platform.PlatformView;

class VdoPlayerPlatformView implements PlatformView, MethodChannel.MethodCallHandler,
        VdoPlayer.PlaybackEventListener {
    private static final String TAG = "VdoPlayerPlatformView";

    @NonNull
    private final VdoPlayerView vdoPlayerView;
    @NonNull
    private final MethodChannel methodChannel;
    @NonNull
    private final EventChannel eventChannel;

    @Nullable
    private VdoPlayer vdoPlayer;
    @Nullable
    private EventChannel.EventSink playerEventSink;

    @Nullable
    private MethodChannel.Result loadResult;
    @Nullable
    private PlaybackState lastPlaybackState;

    //Keeping track of current playback speed to restore it on app resume as its not supported by android SDK.
    private float currentPlaybackSpeed;

    VdoPlayerPlatformView(@NonNull Context context, final int id, BinaryMessenger binaryMessenger,
                          @Nullable final Map<String, Object> creationParams) {
        vdoPlayerView = new VdoPlayerView(context);
        methodChannel = new MethodChannel(binaryMessenger, "com.vdocipher.flutter.vdoplayerview_" + id);
        methodChannel.setMethodCallHandler(this);

        eventChannel = new EventChannel(binaryMessenger, "com.vdocipher.flutter.vdoplayerview.events_" + id);
        eventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            @Override
            public void onListen(Object arguments, EventChannel.EventSink eventSink) {
                playerEventSink = eventSink;
            }

            @Override
            public void onCancel(Object arguments) {
                playerEventSink = null;
            }
        });

        vdoPlayerView.initialize(new PlayerHost.InitializationListener() {
            @Override
            public void onInitializationSuccess(PlayerHost playerHost, VdoPlayer player, boolean restored) {
                Log.i(TAG, "init success");
                player.addPlaybackEventListener(VdoPlayerPlatformView.this);
                vdoPlayer = player;
                methodChannel.invokeMethod("onPlatformPlayerCreated", id);
            }

            @Override
            public void onInitializationFailure(PlayerHost playerHost, ErrorDescription errorDescription) {
                Log.e(TAG, "init failure");
            }
        });
    }

    @NonNull
    @Override
    public View getView() {
        return vdoPlayerView;
    }

    @Override
    public void dispose() {
        vdoPlayerView.packUp();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull MethodChannel.Result result) {
        if (vdoPlayer == null) {
            return;
        }

        switch (call.method) {
            case "load":
                // TODO handle load args parse failure
                Map<String, Object> loadArgs = (Map<String, Object>) call.arguments;
                final boolean restore = (boolean) loadArgs.get("restore");
                if (restore) {
                    // Restore with last saved playback state
                    if (lastPlaybackState == null) {
                        // Nothing to restore with
                        result.success(MessageUtils.loadResultMap(null));
                    } else {
                        // Restore
                        vdoPlayerView.restore(lastPlaybackState);
                        lastPlaybackState = null;
                        loadResult = result;
                    }
                } else {
                    // Load new provided EmbedInfo
                    Map<String, Object> embedInfo = (Map<String, Object>) loadArgs.get("embedInfo");
                    VdoInitParams initParams = new EmbedInfoToVdoInitParams(embedInfo).convert();
                    Log.i("ReceivedParams", "[" + initParams.otp + ", " + initParams.playbackInfo + "]");
                    vdoPlayer.load(initParams);
                    loadResult = result;
                }
                break;
            case "setPlayWhenReady":
                vdoPlayer.setPlayWhenReady((boolean) call.arguments);
                break;

            case "getPlayWhenReady":
                result.success(vdoPlayer.getPlayWhenReady());
                break;

            case "getPlaybackAndBufferedPositions":
                HashMap<String, Object> positions = new HashMap<>();
                long currentTime = vdoPlayer.getCurrentTime();
                long bufferedTime = vdoPlayer.getBufferedTime();
                positions.put("position", currentTime >= 0 ? currentTime : 0);
                positions.put("bufferedPosition", bufferedTime >= 0 ? bufferedTime : 0);
                result.success(positions);
                break;

            case "getDuration":
                result.success(vdoPlayer.getDuration());
                break;

            case "seek":
                vdoPlayer.seekTo((int) call.arguments);
                result.success(null);
                break;

            case "stop":
                vdoPlayerView.packUp();
                result.success(null);
                break;
            case "packUp":
                lastPlaybackState = vdoPlayerView.getLastPlaybackState();
                vdoPlayerView.packUp();
                result.success(null);
                break;
            case "setPlaybackSpeed":
                double speed = (double) call.arguments;
                vdoPlayer.setPlaybackSpeed((float) speed);
                result.success(null);
                break;
            case "setAdaptive":
                vdoPlayer.setSelectedTracks(new Track[]{Track.SET_ADAPTIVE});
                result.success(null);
                break;
            case "setAudioTrack":
                // Fall over; same as video track selection
            case "setVideoTrack":
                int trackId = (int) call.arguments;
                setTrack(trackId);
                result.success(null);
                break;
            case "setSubtitleLanguage":
                String subtitleLang = (String) call.arguments;
                boolean changed = setSubtitleLanguage(subtitleLang);
                result.success(changed);
                break;
            case "getPlaybackProperty":
                String propertyName = (String) call.arguments;
                Object playbackProperty = vdoPlayer.getPlaybackProperty(propertyName);
                result.success(playbackProperty);
                break;
            default:
                result.notImplemented();
        }
    }

    // VdoPlayer.PlaybackEventListener impl

    @Override
    public void onPlayerStateChanged(boolean playWhenReady, int playbackState) {
        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onPlayerStateChanged");
            event.put("playWhenReady", playWhenReady);
            event.put("playbackState", MessageUtils.playerStateName(playbackState));
            playerEventSink.success(event);
        }
    }

    @Override
    public void onSeekTo(long millis) {
        methodChannel.invokeMethod("onSeekTo", millis);
    }

    @Override
    public void onProgress(long millis) {
        methodChannel.invokeMethod("onProgress", millis);
    }

    @Override
    public void onBufferUpdate(long bufferTime) {
        methodChannel.invokeMethod("onBufferUpdate", bufferTime);
    }

    @Override
    public void onPlaybackSpeedChanged(float speed) {
        this.currentPlaybackSpeed = speed;
        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onPlaybackSpeedChanged");
            event.put("value", speed);
            playerEventSink.success(event);
        }
    }

    @Override
    public void onLoading(VdoInitParams vdoInitParams) {
        Log.i(TAG, "onLoading");
        methodChannel.invokeMethod("onLoading", VdoInitParamsToMap.convert(vdoInitParams));
    }

    @Override
    public void onLoaded(VdoInitParams vdoInitParams) {
        Log.i(TAG, "onLoaded");
        methodChannel.invokeMethod("onLoaded", VdoInitParamsToMap.convert(vdoInitParams));
        if (loadResult != null && vdoPlayer != null) {
            //Resetting playback speed
            if (vdoPlayer.getPlaybackSpeed() != currentPlaybackSpeed)
                vdoPlayer.setPlaybackSpeed(currentPlaybackSpeed);
            loadResult.success(MessageUtils.loadResultMap(vdoPlayer.getCurrentMedia()));
            loadResult = null;
        }

        if (playerEventSink != null && vdoPlayer != null) {
            Track[] availableTracks = vdoPlayer.getAvailableTracks();
            Track[] selectedTracks = vdoPlayer.getSelectedTracks();
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onTracksChanged");
            event.put("available", MessageUtils.trackMapList(availableTracks));
            event.put("selected", MessageUtils.trackMapList(selectedTracks));
            playerEventSink.success(event);
        }
    }

    @Override
    public void onLoadError(VdoInitParams vdoInitParams, ErrorDescription errorDescription) {
        Log.e(TAG, "onLoadError " + errorDescription);
        if (loadResult != null) {
            // TODO define error object
            loadResult.error("" + errorDescription.errorCode, errorDescription.errorMsg, null);
            loadResult = null;
        }
    }

    @Override
    public void onMediaEnded(VdoInitParams vdoInitParams) {
        methodChannel.invokeMethod("onMediaEnded", VdoInitParamsToMap.convert(vdoInitParams));
        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onMediaEnded");
            playerEventSink.success(event);
        }
    }

    @Override
    public void onError(VdoInitParams vdoInitParams, ErrorDescription errorDescription) {
        Map<String, Object> arguments = new HashMap<>();
        arguments.put("embedInfo", VdoInitParamsToMap.convert(vdoInitParams));
        arguments.put("errorDescription", MessageUtils.errorInfoMap(errorDescription));
        methodChannel.invokeMethod("onError", arguments);
        if (playerEventSink != null) {
            playerEventSink.error("" + errorDescription.errorCode, errorDescription.errorMsg, null);
        }
    }

    @Override
    public void onTracksChanged(Track[] availableTracks, Track[] selectedTracks) {
        Map<String, Object> arguments = new HashMap<>();
        arguments.put("available", MessageUtils.trackMapList(availableTracks));
        arguments.put("selected", MessageUtils.trackMapList(selectedTracks));
        methodChannel.invokeMethod("onTracksChanged", arguments);

        if (playerEventSink != null) {
            Map<String, Object> event = new HashMap<>();
            event.put("name", "onTracksChanged");
            event.put("available", MessageUtils.trackMapList(availableTracks));
            event.put("selected", MessageUtils.trackMapList(selectedTracks));
            playerEventSink.success(event);
        }
    }

    private void setTrack(final int trackId) {
        if (vdoPlayer == null) {
            return;
        }
        // Find track with trackId in available tracks
        Track match = null;
        for (Track track : vdoPlayer.getAvailableTracks()) {
            if (track.id == trackId) {
                match = track;
                break;
            }
        }

        // If track found, select it
        if (match != null) {
            vdoPlayer.setSelectedTracks(new Track[]{match});
        }
    }

    private boolean setSubtitleLanguage(String lang) {
        if (vdoPlayer == null) {
            return false;
        }
        if (lang == null) {
            // Turn subtitles off
            vdoPlayer.setSelectedTracks(new Track[]{Track.DISABLE_CAPTIONS});
            return true;
        } else {
            // Set provided subtitle language if available
            Track[] tracks = vdoPlayer.getAvailableTracks();
            for (Track track : tracks) {
                if (track.type == Track.TYPE_CAPTIONS && lang.equals(track.language)) {
                    vdoPlayer.setSelectedTracks(new Track[]{track});
                    return true;
                }
            }
            return false;
        }
    }
}
